# licofage

licofage is a tool designed to enhance the accessiblity of the scientific paper *Addition in Dumont-Thomas Numeration Systems in Theory and Practice*. The authors of the paper are O. Carton, JM. Couvreur, M. Delacourt and N. Ollinger.

The implentation is a prototype of a method for generating deterministic finite automata associated with linear equations expressed in the numeration system associated with a given substitution.

Once the installation of the package is complete, the `licofage` command-line tool may be invoked.

The command `licofage -h` provides comprehensive invocation coverage.

